Module mini_functions::common
source · Expand description
Provides access to functions for accessing a collection of mathematical and cryptographic constants. Application Common mathematical constants functionality
Provides access to functions for accessing a collection of mathematical and cryptographic constants.
Modules
- Re-exported macros from cmn providing access to common macros. The
macrosmodule contains functions for generating macros. Macros for the cmn crate.
Structs
- Re-exported
Commontype from cmn providing access to common constants. TheCommonstructure provides a central location to store data that is commonly used throughout the library. The structure implements theSerializeandDeserializetraits from theserdecrate to enable serialization and deserialization of the data. - Re-exported
Constantsstruct from cmn providing math/crypto constants. TheConstantsstructure holds mathematical and hash constants. - Re-exported
Wordsstruct from cmn with common words list. Contains several words for use in generating passphrases.
Functions
- Re-exported
run()function from cmn. This is the main entry point for theCommon (CMN)library.