Struct mini_functions::date::Date

source ·
#[non_exhaustive]
pub struct Date {}
Date Utility

By default, the current date and time in UTC is returned.

Implementations

Get the Date in the stored offset.

Get the day of the date in the stored offset.

The day is a number from 1 to 31.

Get the clock hour in the stored offset.

The hour is a number from 0 to 23. 0 is midnight. 12 is noon.

Get the ISO week number of the date in the stored offset.

The returned value will always be in the range 1..=53.

Get the microsecond of the second in the stored offset.

The returned value will always be in the range 0..1_000_000.

Get the milliseconds within the second in the stored offset.

The returned value will always be in the range 0..1_000.

Get the minute within the hour in the stored offset.

The returned value will always be in the range 0..60.

Get the month of the date in the stored offset.

The month is a number from 1 to 12. January is 1, February is 2, and so on.

Get the nanoseconds within the second in the stored offset.

The returned value will always be in the range 0..1_000_000_000.

Create a new OffsetDateTime in the ISO 8601 format.

Create a new OffsetDateTime with the current date and time (UTC)

Get the UtcOffset.

Get the day of the year of the date in the stored offset.

The returned value will always be in the range 1..=366.

Get the second within the minute in the stored offset.

The returned value will always be in the range 0..60.

Get the Time in the stored offset.

Get the Unix timestamp.

Get the weekday of the date in the stored offset.

This current uses Zellers congruence internally.

Get the year of the date in the stored offset.