macro_rules! hsh {
($($token:tt)*) => { ... };
}Expand description
This macro takes any number of arguments and parses them into a Rust
value. The parsed value is returned wrapped in
hsh::Hash::parse() function call.
macro_rules! hsh {
($($token:tt)*) => { ... };
}This macro takes any number of arguments and parses them into a Rust
value. The parsed value is returned wrapped in
hsh::Hash::parse() function call.