Struct mini_functions::hash::Hash
source · #[non_exhaustive]pub struct Hash { /* private fields */ }Expand description
A struct for storing and verifying hashed passwords based on the blake3 crate.
Implementations
sourceimpl Hash
impl Hash
sourcepub fn entropy(&self) -> f64
pub fn entropy(&self) -> f64
Calculates the entropy of the hash in bits based on the Shannon entropy formula. https://en.wikipedia.org/wiki/Entropy_(information_theory)
sourcepub fn generate_hash(&self) -> String
pub fn generate_hash(&self) -> String
Hashes the password.
sourcepub fn hash_length(&self) -> usize
pub fn hash_length(&self) -> usize
Returns the hash length.
sourcepub fn password_length(&self) -> usize
pub fn password_length(&self) -> usize
Returns the password length.
sourcepub fn set_password(&mut self, password: &str)
pub fn set_password(&mut self, password: &str)
Sets the password and updates the hash.