#[non_exhaustive]
pub struct Password { /* private fields */ }
A random password / passphrase generator. The generated password is a string of three words separated by hyphens. Each word is between 6 and 8 characters long. The first character of each word is capitalized.

Implementations

Calculates the entropy of the generated passphrase. Returns the entropy as a f64.

Returns the hash of the generated passphrase.

Returns the hash length.

Returns true if the generated passphrase is empty. Returns false if the generated passphrase is not empty.

Returns the length of the generated passphrase.

Generates a random passphrase.

Returns the generated passphrase.

Returns the password length.

Sets the generated passphrase.