#[non_exhaustive]
pub struct QRCode { pub data: Vec<u8>, }
The QRCode struct represents a QR code image.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
data: Vec<u8>

The data field holds the data to be encoded in the QR code.

Implementations

The new method creates a new instance of the QRCode struct with the given data.

The from_string method creates a new instance of the QRCode struct by converting the given string data into a vector of bytes

The from_bytes method creates a new instance of the QRCode struct with the given vector of bytes

The to_qrcode method creates a new QrCode value using the data stored in the QRCode struct.

The to_png method creates a new PNG image of the QR code using the data stored in the QRCode

The to_svg method creates a new SVG image of the QR code using the data stored in the QRCode

The colorize method creates a new PNG image of the QR code using the data stored in the QRCode and the given color value to colorize the QR code.

The resize method creates a new PNG image of the QR code using the data stored in the QRCode and the given width and height values to resize the QR code.