macro_rules! rand_int {
($rng:expr, $min:expr, $max:expr) => { ... };
}Expand description
Generate a random integer within the given range using the provided
Random (VRD) struct
macro_rules! rand_int {
($rng:expr, $min:expr, $max:expr) => { ... };
}Generate a random integer within the given range using the provided
Random (VRD) struct