#[non_exhaustive]
pub struct Random { /* private fields */ }
A random number generator based on the linear congruential generator algorithm with the golden ratio as the multiplier.

Implementations

Generates a random boolean value.

Generates a random byte.

Generates a random character.

Chooses a random value from a slice of values.

Generates a random float between 0 and 1.

Generates a random integer between the min and max values.

Creates a new random number generator.

Generates a random number between the min and max values.

Generates a random number between the min and max values.

Generates a random number between the min and max values.