Struct mini_functions::password::Password
source · #[non_exhaustive]pub struct Password { /* private fields */ }Expand description
A random password / passphrase generator. The generated password is a string of three words separated by hyphens. Each word is between 6 and 8 characters long. The first character of each word is capitalized.
Implementations
sourceimpl Password
impl Password
sourcepub fn entropy(&self) -> f64
pub fn entropy(&self) -> f64
Calculates the entropy of the generated passphrase. Returns the entropy as a f64.
sourcepub fn hash_length(&self) -> usize
pub fn hash_length(&self) -> usize
Returns the hash length.
sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the generated passphrase is empty. Returns false if the generated passphrase is not empty.
sourcepub fn new(len: u8, separator: &str, special_chars: Vec<char>) -> Self
pub fn new(len: u8, separator: &str, special_chars: Vec<char>) -> Self
Generates a random passphrase.
sourcepub fn passphrase(&self) -> &str
pub fn passphrase(&self) -> &str
Returns the generated passphrase.
sourcepub fn password_length(&self) -> usize
pub fn password_length(&self) -> usize
Returns the password length.
sourcepub fn set_passphrase(&mut self, passphrase: &str)
pub fn set_passphrase(&mut self, passphrase: &str)
Sets the generated passphrase.