Module mini_functions::random
source · Expand description
Provides a set of utility functions for working with random numbers
Core Random number generator
This crate provides a random number generator based on the linear congruential generator algorithm with the golden ratio as the multiplier.
Structs
A random number generator based on the linear congruential generator
algorithm with the golden ratio as the multiplier.