Struct mini_functions::random::Random
source · #[non_exhaustive]pub struct Random { /* private fields */ }Expand description
A random number generator based on the linear congruential generator algorithm with the golden ratio as the multiplier.
Implementations